Learn R Programming

cmfrec (version 3.5.1-3)

precompute.for.predictions: Precompute matrices to use for predictions

Description

Pre-computes internal matrices which might be used to speed up computations on new data in the CMF and CMF_implicit models. This function does not need to be called when passing `precompute_for_predictions=TRUE`.

Usage

precompute.for.predictions(model)

Value

The same model object, with the pre-calculated matrices inside it.

Arguments

model

A collective matrix factorization model object, for which the pre-computed matrices will be calculated.