Learn R Programming

cmfrec (version 3.5.1-3)

print.cmfrec: Get information about factorization model

Description

Print basic properties of a `cmfrec` object (a base class encompassing all the models in this package).

Usage

# S3 method for cmfrec
print(x, ...)

Value

Returns the same model object that was passes as input.

Arguments

x

An object of class `cmfrec` as returned by functions CMF, CMF_implicit, MostPopular, ContentBased, OMF_explicit, OMF_implicit.

...

Extra arguments (not used).