Pre-computes internal matrices which might be used to speed up computations on new data in the CMF and CMF_implicit models. This function does not need to be called when passing `precompute_for_predictions=TRUE`.
precompute.for.predictions(model)The same model object, with the pre-calculated matrices inside it.
A collective matrix factorization model object, for which the pre-computed matrices will be calculated.